@@ -114,7 +114,7 @@ class ADBPythonAsync(object):
         self.host = host
         self.port = int(port)
         self.adbkey = adbkey
-        self._adb = AdbDeviceTcpAsync(host=self.host, port=self.port, default_transport_timeout_s=DEFAULT_ADB_TIMEOUT_S, banner=b'androidtv')
+        self._adb = AdbDeviceTcpAsync(host=self.host, port=self.port, default_transport_timeout_s=DEFAULT_ADB_TIMEOUT_S)
         self._signer = signer
 
         # keep track of whether the ADB connection is intact
@@ -287,7 +287,7 @@ class ADBPythonAsync(object):
         async with _acquire(self._adb_lock):
             _LOGGER.debug("Taking screencap from %s:%d via adb-shell", self.host, self.port)
             result = await self._adb.shell("screencap -p", decode=False)
-            if result[5:6] == b"\r":
+            if result and result[5:6] == b"\r":
                 return result.replace(b"\r\n", b"\n")
             return result
 
@@ -466,8 +466,8 @@ class ADBServerAsync(object):
 
         Returns
         -------
-        bytes
-            The screencap as a binary .png image
+        bytes, None
+            The screencap as a binary .png image, or ``None`` if there was an ``IndexError`` exception
 
         """
         if not self.available:
@@ -476,7 +476,10 @@ class ADBServerAsync(object):
 
         async with _acquire(self._adb_lock):
             _LOGGER.debug("Taking screencap from %s:%d via ADB server %s:%d", self.host, self.port, self.adb_server_ip, self.adb_server_port)
-            return await self._adb_device.screencap()
+            try:
+                return await self._adb_device.screencap()
+            except IndexError:
+                return None
 
     async def shell(self, cmd):
         """Send an ADB command using an ADB server.
